#
# Copyright 2008,2010 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#

##################################################
# Controller Keys
##################################################
AC_COUPLE_KEY = 'ac_couple'
ALPHA_KEY = 'alpha'
AUTORANGE_KEY = 'autorange'
AVERAGE_KEY = 'average'
AVG_ALPHA_KEY = 'avg_alpha'
USE_PERSISTENCE_KEY = 'use_persistence'
PERSIST_ALPHA_KEY = 'persist_alpha'
BASEBAND_FREQ_KEY = 'baseband_freq'
BETA_KEY = 'beta'
COLOR_MODE_KEY = 'color_mode'
DECIMATION_KEY = 'decimation'
DYNAMIC_RANGE_KEY = 'dynamic_range'
FRAME_RATE_KEY = 'frame_rate'
GAIN_MU_KEY = 'gain_mu'
GAIN_OMEGA_KEY = 'gain_omega'
MARKER_KEY = 'marker'
XY_MARKER_KEY = 'xy_marker'
MSG_KEY = 'msg'
NUM_LINES_KEY = 'num_lines'
OMEGA_KEY = 'omega'
PEAK_HOLD_KEY = 'peak_hold'
TRACE_STORE_KEY = 'trace_store'
TRACE_SHOW_KEY = 'trace_show'
REF_LEVEL_KEY = 'ref_level'
RUNNING_KEY = 'running'
SAMPLE_RATE_KEY = 'sample_rate'
TRIGGER_CHANNEL_KEY = 'trigger_channel'
TRIGGER_LEVEL_KEY = 'trigger_level'
TRIGGER_MODE_KEY = 'trigger_mode'
TRIGGER_SLOPE_KEY = 'trigger_slope'
TRIGGER_SHOW_KEY = 'trigger_show'
XY_MODE_KEY = 'xy_mode'
X_CHANNEL_KEY = 'x_channel'
Y_CHANNEL_KEY = 'y_channel'
T_FRAC_OFF_KEY = 't_frac_off'
T_DIVS_KEY = 't_divs'
T_OFF_KEY = 't_off'
T_PER_DIV_KEY = 't_per_div'
X_DIVS_KEY = 'x_divs'
X_OFF_KEY = 'x_off'
X_PER_DIV_KEY = 'x_per_div'
Y_DIVS_KEY = 'y_divs'
Y_OFF_KEY = 'y_off'
Y_PER_DIV_KEY = 'y_per_div'
MAXIMUM_KEY = 'maximum'
MINIMUM_KEY = 'minimum'
NUM_BINS_KEY = 'num_bins'
FRAME_SIZE_KEY = 'frame_size'
CHANNEL_OPTIONS_KEY = 'channel_options'
SHOW_CONTROL_PANEL_KEY = 'show_control_panel'
